@@ -200,10 +200,6 @@ def _parallel_tasks(commands_to_run):
     ))
 
 
-def _is_network_error_ignored():
-    return not state.env.use_exceptions_for['network'] and state.env.skip_bad_hosts
-
-
 def _execute(task, host, my_env, args, kwargs, jobs, queue, multiprocessing):
     """
     Primary single-host work body of execute()
@@ -232,7 +228,8 @@ def _execute(task, host, my_env, args, kwargs, jobs, queue, multiprocessing):
             def submit(result):
                 queue.put({'name': name, 'result': result})
             try:
-                state.connections.clear()
+                key = normalize_to_string(state.env.host_string)
+                state.connections.pop(key, "")
                 submit(task.run(*args, **kwargs))
             except BaseException, e: # We really do want to capture everything
                 # SystemExit implies use of abort(), which prints its own
@@ -241,16 +238,12 @@ def _execute(task, host, my_env, args, kwargs, jobs, queue, multiprocessing):
                 # clear what host encountered the exception that will
                 # print.
                 if e.__class__ is not SystemExit:
-                    if not (isinstance(e, NetworkError) and
-                            _is_network_error_ignored()):
-                        sys.stderr.write("!!! Parallel execution exception under host %r:\n" % name)
+                    sys.stderr.write("!!! Parallel execution exception under host %r:\n" % name)
                     submit(e)
                 # Here, anything -- unexpected exceptions, or abort()
                 # driven SystemExits -- will bubble up and terminate the
                 # child process.
-                if not (isinstance(e, NetworkError) and
-                        _is_network_error_ignored()):
-                    raise
+                raise
 
         # Stuff into Process wrapper
         kwarg_dict = {
@@ -400,10 +393,7 @@ def execute(task, *args, **kwargs):
             ran_jobs = jobs.run()
             for name, d in ran_jobs.iteritems():
                 if d['exit_code'] != 0:
-                    if isinstance(d['results'], NetworkError) and \
-                            _is_network_error_ignored():
-                        error(d['results'].message, func=warn, exception=d['results'].wrapped)
-                    elif isinstance(d['results'], BaseException):
+                    if isinstance(d['results'], BaseException):
                         error(err, exception=d['results'])
                     else:
                         error(err)
